@@ -106,6 +106,8 @@ class Profile(object):
     :type centroid_region: float
     :param bins: in case binning is set to 'custom', a numpy array containing the binning definition. For an input array of length N, the binning will contain N-1 bins with boundaries set as the values of the input array.
     :type bins: class:`numpy.ndarray`
+    :param cosmo: An :class:`astropy.cosmology` object containing the definition of the cosmological model. If cosmo=None, Planck 2015 cosmology is used.
+    :type cosmo: class:`astropy.cosmology`
     """
     def __init__(self, data=None, center_choice=None, maxrad=None, binsize=None, center_ra=None, center_dec=None,
                  binning='linear', centroid_region=None, bins=None, cosmo=None):
@@ -325,7 +327,7 @@ class Profile(object):
         self.scatter = None
         self.escat = None
 
-    def SBprofile(self, ellipse_ratio=1.0, rotation_angle=0.0, angle_low=0., angle_high=360., box=False, width=None):
+    def SBprofile(self, ellipse_ratio=1.0, rotation_angle=0.0, angle_low=0., angle_high=360., minexp=0.05, box=False, width=None):
         """
         Extract a surface brightness profile and store the results in the input Profile object
 
@@ -348,7 +350,14 @@ class Profile(object):
         img = data.img
         voronoi = self.voronoi
         if not voronoi:
-            exposure = data.exposure
+            exposure = np.copy(data.exposure)
+
+            maxexp = np.max(exposure)
+
+            lowexp = np.where(exposure <= minexp * maxexp)
+
+            exposure[lowexp] = 0.0
+
         else:
             exposure = data.errmap
         bkg = data.bkg
@@ -361,6 +370,7 @@ class Profile(object):
             else:
                 nbin = int(self.maxrad / self.binsize * 60. + 0.5)
                 self.bins = np.arange(self.binsize / 60. / 2., (nbin + 0.5) * self.binsize / 60., self.binsize / 60.)
+                self.bins = self.bins[self.bins<self.maxrad]
                 self.ebins = np.ones(nbin) * self.binsize / 60. / 2.
                 self.nbin = nbin
         else:
@@ -477,10 +487,22 @@ class Profile(object):
             self.bkgcounts = bkgcounts
 
 
-    def MedianSB(self, ellipse_ratio=1.0, rotation_angle=0.0, outsamples=None):
+    def MedianSB(self, ellipse_ratio=1.0, rotation_angle=0.0, nsim=1000, outsamples=None, fitter=None, thin=10):
         """
         Extract the median surface brightness profile in circular annuli from a provided Voronoi binned image, following the method outlined in Eckert et al. 2015
 
+        :param ellipse_ratio: Ratio a/b of major to minor axis in the case of an elliptical annulus definition. Defaults to 1.0, i.e. circular annuli.
+        :type ellipse_ratio: float
+        :param rotation_angle: Rotation angle of the ellipse or box respective to the R.A. axis. Defaults 0.
+        :type rotation_angle: float
+        :param nsim: Number of Monte Carlo realizations of the Voronoi image to be performed
+        :type nsim: int
+        :param outsamples: Name of output FITS file to store the bootstrap realizations of the median profile. Defaults to None
+        :type outsamples: str
+        :param fitter: A :class:`pyproffit.fitter.Fitter` object containing the result of a fit to the background region, for subtraction of the background to the resulting profile
+        :type fitter: class:`pyproffit.fitter.Fitter`
+        :param thin: Number of blocks into which the calculation of the bootstrap will be divided. Increasing thin reduces memory usage drastically, at the cost of a modest increase in computation time.
+        :type thin: int
         """
         data = self.data
         img = data.img
@@ -527,7 +549,7 @@ class Profile(object):
         #    area[i] = len(img[id]) * pixsize ** 2
         #    effexp[i] = 1. # Dummy, but to be consistent with PSF calculation
 
-        all_prof, area = median_all_cov(data, self.bins, self.ebins, rads, nsim=1000)
+        all_prof, area = median_all_cov(data, self.bins, self.ebins, rads, nsim=nsim, fitter=fitter, thin=thin)
         profile, eprof = np.median(all_prof, axis=1), np.std(all_prof, axis=1)
         effexp = np.ones(self.nbin) # Dummy, but to be consistent with PSF calculation
         cov = np.cov(all_prof)
@@ -539,9 +561,23 @@ class Profile(object):
 
         if outsamples is not None:
             hdu = fits.PrimaryHDU(all_prof)
-            hdu.writeto(outsamples)
+            hdu.writeto(outsamples, overwrite=True)
 
     def AzimuthalScatter(self, nsect=12, model=None):
+        '''
+        Compute the azimuthal scatter profile around the loaded profile. The azimuthal scatter is defined as the standard deviation of the surface brightness in equispaced sectors with respect to the azimuthal mean,
+
+        .. math::
+
+            \\Sigma_X(r) = \\frac{1}{N} \\sum_{i=1}^N \\frac{(S_i(r) - \\langle S(r) \\rangle)^2}{\\langle S(r) \\rangle^2}
+
+        with N the number of sectors and :math:`\\langle S(r) \\rangle` the loaded mean surface brightness profile.
+
+        :param nsect: Number of sectors from which the azimuthal scatter will be computed. Defaults to nsect=12
+        :type nsect: int
+        :param model: A :class:`pyproffit.models.Model` object containing the background to be subtracted, in case the scatter is to be computed on background-subtracted profiles. Defaults to None (i.e. no background subtraction).
+        :type model: class:`pyproffit.models.Model`
+        '''
 
         if self.profile is None:
             print('Error: please extract a SB profile first')
@@ -713,7 +749,7 @@ class Profile(object):
                 hdul.append(psfhdu)
             hdul.writeto(outfile, overwrite=True)
 
-    def PSF(self, psffunc=None, psffile=None, psfimage=None, psfpixsize=None, sourcemodel=None):
+    def PSF(self, psffunc=None, psffile=None, psfimage=None, psfpixsize=None, sourcemodel=None, psfmin = 1e-7):
         """
         Function to calculate a PSF convolution matrix given an input PSF image or function.
         To compute the PSF mixing matrix, images of each annuli are convolved with the PSF image using FFT and determine the fraction of photons leaking into neighbouring annuli. FFT-convolved images are then used to determine a mixing matrix. See Eckert et al. 2020 for more details.
@@ -759,13 +795,13 @@ class Profile(object):
             rads = np.hypot(x - self.cx, y - self.cy) * self.data.pixsize  # arcmin
             kernel = None
             if psffunc is not None:
-                psfmin = 1e-7 # truncation radius, i.e. we exclude the regions where the PSF signal is less than this value
+                 # truncation radius, i.e. we exclude the regions where the PSF signal is less than this value
                 kernel = psffunc(rads)
                 norm = np.sum(kernel)
                 # psfmin = 0.
                 frmax = lambda x: psffunc(x) * 2. * np.pi * x / norm - psfmin
                 if frmax(exposure.shape[0] / 2) < 0.:
-                    rmax = brentq(frmax, 1., exposure.shape[0]) / self.data.pixsize  # pixsize
+                    rmax = brentq(frmax, 0., exposure.shape[0]) / self.data.pixsize  # pixsize
                     npix = int(rmax)
                 else:
                     npix = int(exposure.shape[0] / 2)
@@ -837,7 +873,7 @@ class Profile(object):
         ytil = -np.sin(ellang) * (x - self.cx) * pixsize + np.cos(ellang) * (y - self.cy) * pixsize
         rads = ellipse_ratio * np.hypot(xtil, ytil / ellipse_ratio)
         if model is not None:
-            outmod = model.model(rads, *model.params)
+            outmod = model(rads, *model.params)
         else:
             outmod = np.interp(rads, self.bins, self.profile)
         if vignetting:
@@ -853,7 +889,7 @@ class Profile(object):
         hdu.header = head
         hdu.writeto(outfile, overwrite=True)
 
-    def Plot(self, model=None, hmcmod=None, outfile=None, axes=None, figsize=(13, 10),
+    def Plot(self, model=None, samples=None, outfile=None, axes=None, scatter=False, figsize=(13, 10),
              fontsize=40., xscale='log', yscale='log', fmt='o', markersize=7, lw=2,
              data_color='black', bkg_color='green', model_color='blue', **kwargs):
         """
@@ -861,12 +897,14 @@ class Profile(object):
 
         :param model: If model is not None, plot the provided model of type :class:`pyproffit.models.Model` together with the data. Defaults to None
         :type model: class:`pyproffit.models.Model` , optional
-        :param hmcmod: If hmcmod is not None, use the provided HMC trace of type :class:`pyproffit.hmc.HMCModel` to compute the median optimized models and upper and lower envelopes. Defaults to None
-        :type hmcmod: class:`pyproffit.hmc.HMCModel`
+        :param samples: Use parameter samples outputted either by Emcee or HMC optimization to compute the median optimized models and upper and lower envelopes. Defaults to None
+        :type samples: class:`numpy.ndarray`
         :param outfile: If outfile is not None, name of output file to save the plot. Defaults to None
         :type outfile: str , optional
         :param axes: List of 4 numbers defining the X and Y axis ranges for the plot. Gives axes=[x1, x2, y1, y2], the X axis will be set between x1 and x2, and the Y axis will be set between y1 and y2.
         :type axes: list , optional
+        :param scatter: Set whether the azimuthal scatter profile will be displayed instead of the surface brightness profile. Defaults to False.
+        :type scatter: bool
         :param figsize: Size of figure. Defaults to (13, 10)
         :type figsize: tuple , optional
         :param fontsize: Font size of the axis labels. Defaults to 40
@@ -907,29 +945,52 @@ class Profile(object):
         for item in (ax.get_yticklabels()):
             item.set_fontsize(18)
         for item in (ax.get_xticklabels()):
-            item.set_fontsize(0)
+            if model is not None:
+                item.set_fontsize(0)
+            else:
+                item.set_fontsize(18)
 
-        if model is None:
-            plt.xlabel('Radius [arcmin]', fontsize=fontsize)
-            plt.ylabel('SB [cts/s/arcmin$^2$]', fontsize=fontsize)
-        else:
-            plt.ylabel('SB [cts/s/arcmin$^2$]', fontsize=fontsize)
-        plt.yscale(yscale)
-        plt.xscale(xscale)
         if not self.box:
             rads = self.bins
         else:
             rads = self.bins - self.maxrad/2.
-        plt.errorbar(rads, self.profile, xerr=self.ebins, yerr=self.eprof, fmt=fmt, color=data_color, elinewidth=2,
-                     markersize=markersize, capsize=0, mec=data_color, label='Brightness', **kwargs)
-        if self.bkgprof is not None:
-            plt.plot(rads, self.bkgprof, color=bkg_color, lw=lw, label='Background')
-        if model is not None:
-            tmod = model.model(rads, *model.params)
-            if self.psfmat is not None:
-                tmod = np.dot(self.psfmat, tmod)
 
-            plt.plot(rads, tmod, color=model_color, lw=lw, label='Model')
+        mod_med, mod_lo, mod_hi = None, None, None
+        if samples is not None and model is not None:
+
+            mod_med, mod_lo, mod_hi = model_from_samples(rads, model, samples, self.psfmat)
+
+        if model is None:
+            plt.xlabel('Radius [arcmin]', fontsize=fontsize)
+            if not scatter:
+                plt.ylabel('SB [cts/s/arcmin$^2$]', fontsize=fontsize)
+            else:
+                plt.ylabel('$\Sigma_{X}$', fontsize=fontsize)
+        else:
+            plt.ylabel('SB [cts/s/arcmin$^2$]', fontsize=fontsize)
+        plt.yscale(yscale)
+        plt.xscale(xscale)
+
+        if not scatter:
+            plt.errorbar(rads, self.profile, xerr=self.ebins, yerr=self.eprof, fmt=fmt, color=data_color, elinewidth=2,
+                         markersize=markersize, capsize=0, mec=data_color, label='Brightness', **kwargs)
+            if self.data.bkglink is not None:
+                plt.plot(rads, self.bkgprof, color=bkg_color, lw=lw, label='Background')
+            if model is not None and samples is None:
+                tmod = model(rads, *model.params)
+                if self.psfmat is not None:
+                    tmod = np.dot(self.psfmat, tmod)
+
+                plt.plot(rads, tmod, color=model_color, lw=lw, label='Model')
+
+            elif mod_med is not None:
+
+                plt.plot(rads, mod_med, color=model_color, lw=lw, label='Model')
+                plt.fill_between(rads, mod_lo, mod_hi, color=model_color, alpha=0.4)
+
+        else:
+            plt.errorbar(rads, self.scatter, xerr=self.ebins, yerr=self.escat, fmt=fmt, color=data_color, elinewidth=2,
+                         markersize=markersize, capsize=0, mec=data_color, label='Scatter', **kwargs)
         xmin = rads[0] * 0.9
         xmax = rads[len(self.bins) - 1] * 1.1
         ylim = ax.get_ylim()
@@ -942,9 +1003,16 @@ class Profile(object):
             gs1 = gridspec.GridSpec(1, 1)
             gs1.update(left=0.12, right=0.95, wspace=0.0, top=0.35, bottom=0.12)
             ax2 = plt.subplot(gs1[0])
-            chi = (self.profile-tmod)/self.eprof
+
+            if mod_med is None:
+                chi = (self.profile-tmod)/self.eprof
+
+            else:
+                chi = (self.profile - mod_med) / self.eprof
+
             plt.errorbar(rads, chi, yerr=np.ones(len(rads)), fmt=fmt, color=data_color, elinewidth=2,
                      markersize=markersize, capsize=0, mec=data_color)
+
             plt.xlabel('Radius [arcmin]', fontsize=fontsize)
             plt.ylabel('$\chi$', fontsize=fontsize)
             plt.xscale(xscale)
